.. toctree::
   :maxdepth: 2
   :caption: Contents:

   advanced_attention
   estimators
   references
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
